# Add Relations
### On this page
  * [Introduction to Relations](https://help.sap.com/docs/leanix/ea/add-relations#introduction-to-relations)
  * [Explore Best Practices](https://help.sap.com/docs/leanix/ea/add-relations#explore-best-practices)
  * [Add Relations](https://help.sap.com/docs/leanix/ea/add-relations#add-relations)
  * [Monitor Progress Using Metrics](https://help.sap.com/docs/leanix/ea/add-relations#monitor-progress-using-metrics)


Link applications to business capabilities and organizations to show how they’re connected.
